<?php
/**
 * Home Page Options.
 *
 * @package Super Business
 */

$default = super_business_get_default_theme_options();

// Latest Blog Section
$wp_customize->add_section( 'section_blog',
	array(
		'title'      => __( 'Latest News Section', 'super-business' ),
		'priority'   => 100,
		'capability' => 'edit_theme_options',
		'panel'      => 'home_page_panel',
		)
);
// Disable Blog Section
$wp_customize->add_setting('theme_options[enable_blog_section]', 
	array(
	'default' 			=> $default['enable_blog_section'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'super_business_sanitize_checkbox'
	)
);

$wp_customize->add_control('theme_options[enable_blog_section]', 
	array(		
	'label' 	=> __('Enable Section', 'super-business'),
	'description' => __('Go to Customize - Homepage Settings. Select A static page. Set Homepage as Home and Posts page as Blog to show this section.', 'super-business'),
	'section' 	=> 'section_blog',
	'settings'  => 'theme_options[enable_blog_section]',
	'type' 		=> 'checkbox',	
	)
);

// Section Subtitle
$wp_customize->add_setting('theme_options[blog_section_subtitle]', 
	array(
	'default'           => $default['blog_section_subtitle'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'sanitize_text_field'
	)
);

$wp_customize->add_control('theme_options[blog_section_subtitle]', 
	array(
	'label'       => __('Section Subtitle', 'super-business'),
	'section'     => 'section_blog',   
	'settings'    => 'theme_options[blog_section_subtitle]',	
	'active_callback' => 'super_business_blog_active',		
	'type'        => 'text'
	)
);

// Section Title
$wp_customize->add_setting('theme_options[blog_section_title]', 
	array(
	'default'           => $default['blog_section_title'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'sanitize_text_field'
	)
);

$wp_customize->add_control('theme_options[blog_section_title]', 
	array(
	'label'       => __('Section Title', 'super-business'),
	'section'     => 'section_blog',   
	'settings'    => 'theme_options[blog_section_title]',	
	'active_callback' => 'super_business_blog_active',		
	'type'        => 'text'
	)
);

// Blog Number.
$wp_customize->add_setting( 'theme_options[blog_number]',
	array(
		'default'           => $default['blog_number'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'super_business_sanitize_number_range',
		)
);
$wp_customize->add_control( 'theme_options[blog_number]',
	array(
		'label'       		=> __( 'Number of Posts', 'super-business' ),
		'description' 		=> __('Save & Refresh the customizer to see its effect. Maximum is 50.', 'super-business'),
		'section'     		=> 'section_blog',
		'active_callback' 	=> 'super_business_blog_active',		
		'type'        		=> 'number',
		'input_attrs' 		=> array( 
			'min' => 1, 
			'max' => 50, 
			'step' => 1, 
			'style' => 'width: 115px;' 
		),
	)
);

$blog_number = super_business_get_option( 'blog_number' );

// Setting Blog Category.
$wp_customize->add_setting( 'theme_options[blog_category]',
	array(
	'default'           => $default['blog_category'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'absint',
	)
);
$wp_customize->add_control(
	new super_business_Dropdown_Taxonomies_Control( $wp_customize, 'theme_options[blog_category]',
		array(
		'label'    => __( 'Select Category', 'super-business' ),
		'section'  => 'section_blog',
		'settings' => 'theme_options[blog_category]',	
		'active_callback' => 'super_business_blog_active',		
		)
	)
);
